package com.antai.sport.http.server.management.api.business.series.controller;

import com.antai.sport.http.server.common.base.Result;
import com.antai.sport.http.server.management.api.annotation.LoginUser;
import com.antai.sport.http.server.management.api.business.series.dto.SeriesListQueryDTO;
import com.antai.sport.http.server.management.api.business.series.dto.SeriesSaveDTO;
import com.antai.sport.http.server.management.api.business.series.service.SeriesService;
import com.antai.sport.http.server.management.api.business.series.vo.SeriesListPageVO;
import com.antai.sport.http.server.repository.series.entity.Series;
import com.antai.sport.http.server.repository.sys.entity.SysUser;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

import static com.antai.sport.http.server.common.util.ResultUtil.success;

@RestController
@RequestMapping("/series")
@Api(tags = {"系列赛"})
public class SeriesController {

    @Resource
    private SeriesService seriesService;

    /**
     * 加载系列赛列表
     *
     * @param dto
     * @return
     */
    @PostMapping("list")
    @ApiOperation("列表")
    public ResponseEntity<Result<SeriesListPageVO>> getSeriesList(@RequestBody SeriesListQueryDTO dto) {
        return success(seriesService.getSeriesList(dto));
    }

    @GetMapping("{id}")
    @ApiOperation("明细")
    public ResponseEntity<Result<Series>> getSeries(@PathVariable("id") Long id) {
        return success(seriesService.getSeries(id));
    }

    @PostMapping
    public ResponseEntity<Result> saveSeries(@RequestBody SeriesSaveDTO series, @LoginUser SysUser loginUser) {
        seriesService.saveSeries(series, loginUser);
        return success();
    }

    @PutMapping("publish/{id}")
    public ResponseEntity<Result> publishSeries(@PathVariable("id") Long id) {
        seriesService.publishSeries(id);
        return success();
    }

    @PutMapping("finished/{id}")
    public ResponseEntity<Result> finishedSeries(@PathVariable("id") Long id) {
        seriesService.finishedSeries(id);
        return success();
    }

    @DeleteMapping("{id}")
    public ResponseEntity<Result> deletedSeries(@PathVariable("id") Long id) {
        seriesService.deletedSeries(id);
        return success();
    }

}
