package com.antai.sport.http.server.management.api.business.series.service;

import com.antai.sport.http.server.common.exception.BusinessException;
import com.antai.sport.http.server.management.api.business.series.converter.SeriesConverter;
import com.antai.sport.http.server.management.api.business.series.dto.SeriesListQueryDTO;
import com.antai.sport.http.server.management.api.business.series.dto.SeriesSaveDTO;
import com.antai.sport.http.server.management.api.business.series.mapper.SeriesBusinessMapper;
import com.antai.sport.http.server.management.api.business.series.vo.SeriesListPageVO;
import com.antai.sport.http.server.management.api.business.series.vo.SeriesListVO;
import com.antai.sport.http.server.repository.series.entity.Series;
import com.antai.sport.http.server.repository.series.mapper.SeriesMapper;
import com.antai.sport.http.server.repository.sys.entity.SysUser;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.metadata.OrderItem;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.LocalDateTime;

@Service
public class SeriesService {
    @Resource
    private SeriesBusinessMapper seriesBusinessMapper;
    @Resource
    private SeriesMapper seriesMapper;

    @Resource
    private SeriesConverter seriesConverter;

    public SeriesListPageVO getSeriesList(SeriesListQueryDTO dto) {
        SeriesListPageVO result = new SeriesListPageVO();
        Page<SeriesListVO> pageParam = new Page<>(dto.getPageNo(), dto.getPageSize());
        pageParam.addOrder(new OrderItem("id", false));
        IPage<SeriesListVO> seriesListPage = seriesBusinessMapper.getSeriesList(pageParam, dto);
        result.setPageNo(dto.getPageNo());
        result.setTotalCount(seriesListPage.getTotal());
        result.setData(seriesListPage.getRecords());
        return result;
    }

    public Series getSeries(Long id) {
        Series series;
        if (id == null || id == 0) {
            series = new Series();
            series.setStatus(10);
            series.setApplyNum(0);

        } else {
            series = seriesMapper.selectById(id);
            if (series == null) {
                throw new BusinessException("您查询的系列赛不存在");
            }
        }
        return series;
    }

    public void saveSeries(SeriesSaveDTO dto, SysUser loginUser) {
        Series series = seriesConverter.toSeries(dto);
        if (series.getId() != null && series.getId() > 0) {
            series.setUpdateBy(loginUser.getId());
            series.setUpdateTime(LocalDateTime.now());
            seriesMapper.updateById(series);
        } else {
            series.setStatus(10);
            series.setApplyNum(0);
            series.setFinished(false);
            series.setCreateBy(loginUser.getId());
            series.setCreateTime(LocalDateTime.now());
            seriesMapper.insert(series);
        }
    }

    public void publishSeries(Long id) {
        Series series = seriesMapper.selectById(id);
        if (series.getStatus().equals(10)) {
            series.setStatus(20);
        } else {
            series.setStatus(10);
        }
        seriesMapper.updateById(series);
    }

    public void finishedSeries(Long id) {
        Series series = seriesMapper.selectById(id);
        if (series.getFinished()) {
            series.setFinished(false);
        } else {
            series.setFinished(true);
        }
        seriesMapper.updateById(series);
    }

    public void deletedSeries(Long id) {
        Series series = seriesMapper.selectById(id);
        series.setDeleted(1);
        seriesMapper.updateById(series);
    }
}
